@@ -3,7 +3,6 @@
 #endif
 
 #include <string.h>
-#include <libgnome/gnome-macros.h>
 #include <glib/gi18n.h>
 #include <libgnomevfs/gnome-vfs.h>
 #include <libgnomevfs/gnome-vfs-directory.h>
@@ -62,7 +61,6 @@ typedef struct {
 
 /* Signal IDs */
 enum {
-	LIST_PREPARED,
 	IMAGE_ADDED,
 	IMAGE_REMOVED,
 	LAST_SIGNAL
@@ -186,16 +184,6 @@ eog_image_list_class_init (EogImageListClass *klass)
 	object_class->finalize = eog_image_list_finalize;
 	object_class->dispose = eog_image_list_dispose;
 
-	eog_image_list_signals[LIST_PREPARED] = 
-		g_signal_new ("list-prepared",
-			      G_TYPE_FROM_CLASS (object_class),
-			      G_SIGNAL_RUN_FIRST,
-			      G_STRUCT_OFFSET (EogImageListClass, list_prepared),
-			      NULL,
-			      NULL,
-			      g_cclosure_marshal_VOID__VOID,
-			      G_TYPE_NONE,
-			      0);
 	eog_image_list_signals[IMAGE_ADDED] =
 		g_signal_new ("image-added",
 			      G_TYPE_FROM_CLASS (object_class),
@@ -396,6 +384,10 @@ is_supported_mime_type (const char *mime_type)
 	GQuark quark;
 	GSList *result;
 
+	if (mime_type == NULL) {
+		return FALSE;
+	}
+
 	if (supported_mime_types == NULL) {
 		supported_mime_types = get_supported_mime_types ();
 	}
@@ -423,14 +415,14 @@ cleanup_dead_files (EogImageList *list)
 	while (node != NULL && !found) {
 		GnomeVFSURI *uri = eog_image_get_uri(node->data);
 		if (!gnome_vfs_uri_exists (uri)) {
-			remove = g_list_append (remove, (gpointer)position);
+			remove = g_list_append (remove, GINT_TO_POINTER (position));
 		}	
 		node = node->next;		
 		position++;
 	}
 
 	while (remove) {
-		gint pos = (gint)remove->data;
+		gint pos = GPOINTER_TO_INT (remove->data);
 		EogIter *iter = eog_image_list_get_iter_by_pos (list, pos);
 
 		if (iter) {
