@@ -1583,7 +1583,8 @@ eog_image_free_mem_private (EogImage *image)
 
 #ifdef HAVE_LCMS
 		if (priv->profile != NULL) {
-		  cmsCloseProfile (priv->profile);
+			cmsCloseProfile (priv->profile);
+			priv->profile = NULL;
 		}
 #endif
 		
@@ -1791,9 +1792,11 @@ eog_image_get_exif_orientation (EogImage *img)
 #ifdef HAVE_EXIF
 	if (priv->exif != NULL) {
 		ExifEntry *e = exif_data_get_entry (priv->exif, EXIF_TAG_ORIENTATION);
-		ExifByteOrder o = exif_data_get_byte_order (e->parent->parent);
-		if (e->data != NULL)
+
+		if (e != NULL && e->data != NULL) {
+			ExifByteOrder o = exif_data_get_byte_order (e->parent->parent);
 			orientation = exif_get_short (e->data, o);
+		}
 	}
 #endif /* HAVE_EXIF */
 
